<?php

namespace Litecms\MatrixMember\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\MatrixMember\Models\MatrixMember;

class MatrixMemberPolicy
{

    /**
     * Determine if the given user can view the matrix_member.
     *
     * @param UserPolicy $user
     * @param MatrixMember $matrix_member
     *
     * @return bool
     */
    public function view(UserPolicy $user, MatrixMember $matrix_member)
    {
        if ($user->canDo('matrix_member.matrix_member.view') && $user->isAdmin()) {
            return true;
        }

        return $matrix_member->user_id == user_id() && $matrix_member->user_type == user_type();
    }

    /**
     * Determine if the given user can create a matrix_member.
     *
     * @param UserPolicy $user
     * @param MatrixMember $matrix_member
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('matrix_member.matrix_member.create');
    }

    /**
     * Determine if the given user can update the given matrix_member.
     *
     * @param UserPolicy $user
     * @param MatrixMember $matrix_member
     *
     * @return bool
     */
    public function update(UserPolicy $user, MatrixMember $matrix_member)
    {
        if ($user->canDo('matrix_member.matrix_member.edit') && $user->isAdmin()) {
            return true;
        }

        return $matrix_member->user_id == user_id() && $matrix_member->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given matrix_member.
     *
     * @param UserPolicy $user
     * @param MatrixMember $matrix_member
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MatrixMember $matrix_member)
    {
        return $matrix_member->user_id == user_id() && $matrix_member->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given matrix_member.
     *
     * @param UserPolicy $user
     * @param MatrixMember $matrix_member
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MatrixMember $matrix_member)
    {
        if ($user->canDo('matrix_member.matrix_member.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given matrix_member.
     *
     * @param UserPolicy $user
     * @param MatrixMember $matrix_member
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MatrixMember $matrix_member)
    {
        if ($user->canDo('matrix_member.matrix_member.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
