<?php

namespace Litecms\MatrixMember\Providers;

use Illuminate\Support\ServiceProvider;

class MatrixMemberServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'matrix_member');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'matrix_member');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.matrix_member', function ($app) {
            return $this->app->make('Litecms\MatrixMember\MatrixMember');
        });

                // Bind MatrixMember to repository
        $this->app->bind(
            'Litecms\MatrixMember\Interfaces\MatrixMemberRepositoryInterface',
            \Litecms\MatrixMember\Repositories\Eloquent\MatrixMemberRepository::class
        );

        $this->app->register(\Litecms\MatrixMember\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\MatrixMember\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\MatrixMember\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.matrix_member'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/matrix_member.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/matrix_member')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/matrix_member')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
